@@ -2,9 +2,10 @@ from .menu import Menu
 from .text import Text
 from .chooser import choose
 from .selector import selector
+from .actions import actions
 from .list import List, Scrollbar, ColumnList, Header
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 __all__ = (
         'Menu',
         'Text',
@@ -13,5 +14,6 @@ __all__ = (
         'Scrollbar',
         'ColumnList',
         'Header',
-        'selector'
+        'selector',
+        'actions',
         )
