@@ -6,7 +6,7 @@ class Cbreak:
         curses.cbreak()
 
     def __exit__(self, *args):
-        curses.nocbreak
+        curses.nocbreak()
 
 
 class Window:
